"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const request = require("request");
const xml2js_1 = require("xml2js");
var Priority;
(function (Priority) {
    Priority[Priority["VeryLow"] = -2] = "VeryLow";
    Priority[Priority["Moderate"] = -1] = "Moderate";
    Priority[Priority["Normal"] = 0] = "Normal";
    Priority[Priority["High"] = 1] = "High";
    Priority[Priority["Emergency"] = 2] = "Emergency";
})(Priority = exports.Priority || (exports.Priority = {}));
class Prowl {
    constructor(apiEndpoint) {
        this.apiEndpoint = apiEndpoint;
        if (!this.apiEndpoint) {
            this.apiEndpoint = 'https://api.prowlapp.com/publicapi';
        }
    }
    getApiEndpoint() {
        return this.apiEndpoint;
    }
    add(parameters) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = {
                apikey: parameters.apiKey,
                application: parameters.application,
                event: parameters.event,
                description: parameters.description
            };
            if (parameters.providerKey) {
                data['providerkey'] = parameters.providerKey;
            }
            if (parameters.priority) {
                data['priority'] = parameters.priority;
            }
            if (parameters.url) {
                data['url'] = parameters.url;
            }
            let result = yield this.doRequest('add', 'POST', data);
            return {
                remainingCalls: parseInt(result.prowl.success[0].$.remaining),
                remainingCallsResetDate: parseInt(result.prowl.success[0].$.resetdate)
            };
        });
    }
    verify(apiKey, providerKey) {
        return __awaiter(this, void 0, void 0, function* () {
            let ret;
            try {
                let data = { apikey: apiKey };
                if (providerKey) {
                    data['providerkey'] = providerKey;
                }
                let result = yield this.doRequest('verify', 'GET', data);
                ret = {
                    valid: true,
                    remainingCalls: parseInt(result.prowl.success[0].$.remaining),
                    remainingCallsResetDate: parseInt(result.prowl.success[0].$.resetdate)
                };
            }
            catch (error) {
                if (error.code === 401) {
                    ret = { valid: false };
                }
                else {
                    throw error;
                }
            }
            return ret;
        });
    }
    retrieveToken(providerKey) {
        return __awaiter(this, void 0, void 0, function* () {
            let result = yield this.doRequest('retrieve/token', 'GET', {
                providerkey: providerKey
            });
            return {
                token: result.prowl.retrieve[0].$.token,
                url: result.prowl.retrieve[0].$.url,
                remainingCalls: parseInt(result.prowl.success[0].$.remaining),
                remainingCallsResetDate: parseInt(result.prowl.success[0].$.resetdate)
            };
        });
    }
    retrieveApikey(providerKey, token) {
        return __awaiter(this, void 0, void 0, function* () {
            let result = yield this.doRequest('retrieve/apikey', 'GET', {
                providerkey: providerKey,
                token: token
            });
            return {
                apikey: result.prowl.retrieve[0].$.apikey,
                remainingCalls: parseInt(result.prowl.success[0].$.remaining),
                remainingCallsResetDate: parseInt(result.prowl.success[0].$.resetdate)
            };
        });
    }
    doRequest(endpoint, method, data) {
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((resolve, reject) => {
                let options = {
                    method: method
                };
                if (method === 'POST') {
                    options['form'] = data;
                }
                else {
                    options['qs'] = data;
                }
                request(this.apiEndpoint + '/' + endpoint, options, (error, response, body) => {
                    xml2js_1.parseString(body, (err, result) => {
                        if (response.statusCode === 200) {
                            resolve(result);
                        }
                        else {
                            reject({
                                code: parseInt(result.prowl.error[0]['$'].code),
                                message: result.prowl.error[0]['_']
                            });
                        }
                    });
                });
            });
        });
    }
}
exports.default = Prowl;
//# sourceMappingURL=Prowl.js.map